@@ -120,7 +120,7 @@ protected:
     void keyPressEvent(QKeyEvent *event) override;
 
 private slots:
-    void checkUnckeckItem();
+    void checkUncheckItem();
     void cleanup();
     void cmdDone();
     void cmdStart();
@@ -187,6 +187,8 @@ private:
     Cmd cmd;
     LockFile *lock_file {};
     QHash<QString, VersionNumber> listInstalledVersions();
+    QIcon qicon_installed;
+    QIcon qicon_upgradable;
     QList<PopularInfo> popular_apps;
     QLocale locale;
     QMap<QString, PackageInfo> backports_list;
@@ -275,7 +277,7 @@ private:
     void setConnections() const;
     void setCurrentTree();
     void setDirty();
-    void setIcons() const;
+    void setIcons();
     void setProgressDialog();
     void setSearchFocus() const;
     void setup();
